#[repr(C)]pub struct DeviceGetResolutionResponse {
pub resolution: u8,
}Fields
resolution: u8Trait Implementations
Sourceimpl Clone for DeviceGetResolutionResponse
impl Clone for DeviceGetResolutionResponse
Sourcefn clone(&self) -> DeviceGetResolutionResponse
fn clone(&self) -> DeviceGetResolutionResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetResolutionResponse
impl Debug for DeviceGetResolutionResponse
Sourceimpl<'a, ___E> Encode<DeviceGetResolutionResponse, ___E> for &'a DeviceGetResolutionResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetResolutionResponse, ___E> for &'a DeviceGetResolutionResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetResolutionResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetResolutionResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetResolutionResponse, ___E> for DeviceGetResolutionResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetResolutionResponse, ___E> for DeviceGetResolutionResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetResolutionResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetResolutionResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetResolutionResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetResolutionResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceGetResolutionResponse>, ___E> for &'a DeviceGetResolutionResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetResolutionResponse: Encode<DeviceGetResolutionResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceGetResolutionResponse>, ___E> for &'a DeviceGetResolutionResponsewhere
___E: Encoder + ?Sized,
&'a DeviceGetResolutionResponse: Encode<DeviceGetResolutionResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetResolutionResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetResolutionResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceGetResolutionResponse>, ___E> for DeviceGetResolutionResponsewhere
___E: Encoder + ?Sized,
DeviceGetResolutionResponse: Encode<DeviceGetResolutionResponse, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceGetResolutionResponse>, ___E> for DeviceGetResolutionResponsewhere
___E: Encoder + ?Sized,
DeviceGetResolutionResponse: Encode<DeviceGetResolutionResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceGetResolutionResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceGetResolutionResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceGetResolutionResponse> for DeviceGetResolutionResponse
impl FromWire<DeviceGetResolutionResponse> for DeviceGetResolutionResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetResolutionResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetResolutionResponse, Self>
Sourcefn from_wire(wire: DeviceGetResolutionResponse) -> Self
fn from_wire(wire: DeviceGetResolutionResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetResolutionResponse> for DeviceGetResolutionResponse
impl FromWireRef<DeviceGetResolutionResponse> for DeviceGetResolutionResponse
Sourcefn from_wire_ref(wire: &DeviceGetResolutionResponse) -> Self
fn from_wire_ref(wire: &DeviceGetResolutionResponse) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceGetResolutionResponse
impl Hash for DeviceGetResolutionResponse
Sourceimpl Ord for DeviceGetResolutionResponse
impl Ord for DeviceGetResolutionResponse
Sourcefn cmp(&self, other: &DeviceGetResolutionResponse) -> Ordering
fn cmp(&self, other: &DeviceGetResolutionResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for DeviceGetResolutionResponse
impl PartialOrd for DeviceGetResolutionResponse
impl Copy for DeviceGetResolutionResponse
impl Eq for DeviceGetResolutionResponse
impl StructuralPartialEq for DeviceGetResolutionResponse