#[repr(C)]pub struct DeviceGetSampleResponse {
pub value: Uint32,
}Expand description
The wire type corresponding to DeviceGetSampleResponse.
Fields
value: Uint32Trait Implementations
Sourceimpl Clone for DeviceGetSampleResponse
impl Clone for DeviceGetSampleResponse
Sourcefn clone(&self) -> DeviceGetSampleResponse
fn clone(&self) -> DeviceGetSampleResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetSampleResponse
impl Constrained for DeviceGetSampleResponse
Sourceimpl Debug for DeviceGetSampleResponse
impl Debug for DeviceGetSampleResponse
Sourceimpl<___D> Decode<___D> for DeviceGetSampleResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetSampleResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetSampleResponse, ___E> for &'a DeviceGetSampleResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetSampleResponse, ___E> for &'a DeviceGetSampleResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSampleResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSampleResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetSampleResponse, ___E> for DeviceGetSampleResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetSampleResponse, ___E> for DeviceGetSampleResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetSampleResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetSampleResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSampleResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSampleResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetSampleResponse, ___E> for DeviceGetSampleResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<DeviceGetSampleResponse, ___E> for DeviceGetSampleResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetSampleResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetSampleResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetSampleResponse> for DeviceGetSampleResponse
impl FromWire<DeviceGetSampleResponse> for DeviceGetSampleResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetSampleResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetSampleResponse, Self>
Sourcefn from_wire(wire: DeviceGetSampleResponse) -> Self
fn from_wire(wire: DeviceGetSampleResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetSampleResponse> for DeviceGetSampleResponse
impl FromWireRef<DeviceGetSampleResponse> for DeviceGetSampleResponse
Sourcefn from_wire_ref(wire: &DeviceGetSampleResponse) -> Self
fn from_wire_ref(wire: &DeviceGetSampleResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetSampleResponse
impl IntoNatural for DeviceGetSampleResponse
Sourcetype Natural = DeviceGetSampleResponse
type Natural = DeviceGetSampleResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetSampleResponse
impl Wire for DeviceGetSampleResponse
Sourcetype Narrowed<'de> = DeviceGetSampleResponse
type Narrowed<'de> = DeviceGetSampleResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.